[cfe-commits] r54769 - /cfe/trunk/test/CodeGen/c-strings.c

Nuno Lopes nunoplopes at sapo.pt
Wed Aug 13 16:28:59 PDT 2008


Author: nlopes
Date: Wed Aug 13 18:28:57 2008
New Revision: 54769

URL: http://llvm.org/viewvc/llvm-project?rev=54769&view=rev
Log:
make sure the size of constant arrays is respected

Modified:
    cfe/trunk/test/CodeGen/c-strings.c

Modified: cfe/trunk/test/CodeGen/c-strings.c
URL: http://llvm.org/viewvc/llvm-project/cfe/trunk/test/CodeGen/c-strings.c?rev=54769&r1=54768&r2=54769&view=diff

==============================================================================
--- cfe/trunk/test/CodeGen/c-strings.c (original)
+++ cfe/trunk/test/CodeGen/c-strings.c Wed Aug 13 18:28:57 2008
@@ -1,7 +1,8 @@
 // RUN: clang -emit-llvm -o %t %s &&
 // RUN: grep "hello" %t | count 3 &&
 // RUN: grep 'c"hello\\00"' %t | count 2 &&
 // RUN: grep 'c"hello\\00\\00\\00"' %t | count 1
 
 /* Should be 3 hello string, two global (of different sizes), the rest
    are shared. */
@@ -32,3 +33,4 @@
   gaz(&x);
 }
 
+char x[3] = "ola";
@@ -1,7 +1,8 @@
 // RUN: grep "hello" %t | count 3 &&
 // RUN: grep 'c"hello\\00"' %t | count 2 &&
-// RUN: grep 'c"hello\\00\\00\\00"' %t | count 1
+// RUN: grep 'c"hello\\00\\00\\00"' %t | count 1 &&
+// RUN: grep 'c"ola"' %t | count 1
 
 /* Should be 3 hello string, two global (of different sizes), the rest





More information about the cfe-commits mailing list